## dbt-snowflake 1.10.1 - September 05, 2025

### Features

- Support Iceberg REST with Catalog Linked Databases in Snowflake ([#1251](https://github.com/dbt-labs/dbt-adapters/issues/1251))

### Fixes

- handle non-model node types being passed to generate_database_name ([#1309](https://github.com/dbt-labs/dbt-adapters/issues/1309))
